#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['qtico']

package_data = \
{'': ['*']}

install_requires = \
['PyQt5']

setup(name='qtico',
      version='0.1',
      description='Tools for using cross-platform Qt icon themes.',
      author='Philipp A.',
      author_email='flying-sheep@web.de',
      url='http://github.com/flying-sheep/qtico',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      python_requires='>=3.5',
     )
